package come.stormborntales.notevault.ui.screens

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.*
import androidx.compose.ui.unit.dp

@Composable
fun AddNoteDialog(
    onDismiss: () -> Unit,
    onSave: (title: String, composer: String?, year: Int?, genre: String?, description: String?) -> Unit,
    initialTitle: String = "",
    initialComposer: String? = null,
    initialYear: Int? = null,
    initialGenre: String? = null,
    initialDescription: String? = null
) {
    var title by remember { mutableStateOf(initialTitle) }
    var composer by remember { mutableStateOf(initialComposer ?: "") }
    var yearText by remember { mutableStateOf(initialYear?.toString() ?: "") }
    var genre by remember { mutableStateOf(initialGenre ?: "") }
    var description by remember { mutableStateOf(initialDescription ?: "") }
    var showTitleError by remember { mutableStateOf(false) }


    AlertDialog(
        onDismissRequest = onDismiss,
        confirmButton = {
            TextButton(onClick = {
                if (title.isBlank()) {
                    showTitleError = true
                } else {
                    val year = yearText.toIntOrNull()
                    onSave(
                        title.trim(),
                        composer.takeIf { it.isNotBlank() },
                        year,
                        genre.takeIf { it.isNotBlank() },
                        description.takeIf { it.isNotBlank() }
                    )
                }
            }) {
                Text("Speichern")
            }
        },
        dismissButton = {
            TextButton(onClick = onDismiss) {
                Text("Abbrechen")
            }
        },
        title = {
            Text("Notenblatt hinzufügen", style = MaterialTheme.typography.titleLarge)
        },
        text = {
            Column(modifier = Modifier.verticalScroll(rememberScrollState())) {
                OutlinedTextField(
                    value = title,
                    onValueChange = {
                        title = it
                        if (it.isNotBlank()) showTitleError = false
                    },
                    label = { Text("Titel*") },
                    isError = showTitleError,
                    singleLine = true,
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(vertical = 4.dp)
                )
                if (showTitleError) {
                    Text(
                        "Titel darf nicht leer sein",
                        color = MaterialTheme.colorScheme.error,
                        style = MaterialTheme.typography.bodySmall,
                        modifier = Modifier.padding(start = 16.dp, bottom = 4.dp)
                    )
                }

                OutlinedTextField(
                    value = composer,
                    onValueChange = { composer = it },
                    label = { Text("Komponist (optional)") },
                    singleLine = true,
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(vertical = 4.dp)
                )

                OutlinedTextField(
                    value = yearText,
                    onValueChange = { yearText = it.filter { c -> c.isDigit() } },
                    label = { Text("Erscheinungsjahr (optional)") },
                    singleLine = true,
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(vertical = 4.dp)
                )

                OutlinedTextField(
                    value = genre,
                    onValueChange = { genre = it },
                    label = { Text("Genre (optional)") },
                    singleLine = true,
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(vertical = 4.dp)
                )

                OutlinedTextField(
                    value = description,
                    onValueChange = { description = it },
                    label = { Text("Beschreibung (optional)") },
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(vertical = 4.dp),
                    maxLines = 4
                )
            }
        }
    )
}
