package come.stormborntales.notevault.ui.viewmodel

import android.content.Context
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.net.Uri
import android.util.Log
import android.webkit.MimeTypeMap
import androidx.lifecycle.ViewModel
import androidx.lifecycle.asLiveData
import androidx.lifecycle.viewModelScope
import come.stormborntales.notevault.data.local.entity.NoteEntity
import come.stormborntales.notevault.data.repository.NoteRepository
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import java.io.File
import androidx.core.graphics.scale

class NoteViewModel(
    private val repository: NoteRepository,
) : ViewModel() {
    val notes = repository.allNotes.asLiveData()

    fun createPreviewImage(context: Context, uri: Uri): File? {
       return try {
           val inputStream = context.contentResolver.openInputStream(uri)
           val originalBitmap = BitmapFactory.decodeStream(inputStream) ?: return null

           val previewBitmap = originalBitmap.scale(128, 128, false)
           val previewFile = File(context.filesDir, "preview_${System.currentTimeMillis()}.jpg")
           previewFile.outputStream().use { out ->
               previewBitmap.compress(Bitmap.CompressFormat.JPEG, 75, out)
           }
           previewFile
       } catch (e: Exception) {
           e.printStackTrace()
           null
       }
    }

    fun addNote(context: Context, title: String, composer: String?, year: Int?, genre: String?, description: String?, selectedUris: List<Uri>, onDone:() -> Unit) {
        viewModelScope.launch(Dispatchers.IO) {
            val copiedUris = selectedUris.mapNotNull { uri ->
                try {
                    val inputStream = context.contentResolver.openInputStream(uri)
                    val extension = MimeTypeMap.getSingleton()
                        .getExtensionFromMimeType(context.contentResolver.getType(uri)) ?: "jpg"

                    val outputFile = File(context.filesDir, "note_${System.currentTimeMillis()}.$extension")
                    inputStream?.use { input ->
                        outputFile.outputStream().use { output ->
                            input.copyTo(output)
                        }
                    }
                    Log.d("NoteViewModel", "NoteEntityFile" + outputFile.absolutePath)
                    Uri.fromFile(outputFile).toString() // speichern als String
                } catch (e: Exception) {
                    e.printStackTrace()
                    null
                }
            }

            if (copiedUris.isNotEmpty()) {
                val preview_image_path = createPreviewImage(context, uri = selectedUris[0])

                val note = NoteEntity(
                    title = title,
                    images = copiedUris, // muss als List<String> gespeichert sein
                    composer = composer,
                    year = year,
                    genre = genre,
                    description = description,
                    imagePreview = preview_image_path.toString()
                )

                repository.insert(note)
            }

            onDone()
        }
    }

    fun deleteNote(note: NoteEntity) {
        viewModelScope.launch {
            repository.delete(note)
        }
    }

    fun updateNote(
        editedNote: NoteEntity,
        updatedTitle: String,
        updatedComposer: String?,
        updatedYear: Int?,
        updatedGenre: String?,
        updatedDescription: String?,
        onDone: () -> Unit
    ) {
        viewModelScope.launch {
            editedNote.title = updatedTitle
            editedNote.year = updatedYear;
            editedNote.composer = updatedComposer
            editedNote.genre = updatedGenre
            editedNote.description = updatedDescription

            repository.update(editedNote)

            onDone()
        }
    }
}
